@@ -19,7 +19,7 @@ class PbbtReport(ConsoleReport):
 
 @Test
 class TidyPyCase(BaseCase):
-    class Input(object):  # noqa: pydocstyle:D106
+    class Input:  # noqa: pydocstyle:D106
         tidypy = Field(
             maybe(str),
             hint='The path to the base of project. Defaults to CWD.',
